@@ -33,10 +33,7 @@
 EV_Win32Mouse::EV_Win32Mouse(EV_EditEventMapper * pEEM)
 :	EV_Mouse(pEEM),
 	m_iCaptureCount(0),
-	m_embCaptured(0),
-	m_clickState(0),		// no click
-	m_contextState(0)
-
+	m_embCaptured(0)
 {
 	reset();
 }
@@ -243,7 +240,13 @@ void EV_Win32Mouse::onDoubleClick(AV_View * pView,
 	short x = (unsigned short) pView->getGraphics()->tlu(xPos);
 	short y = (unsigned short) pView->getGraphics()->tlu(yPos);
 
+	// the buttonDown event does not always happen prior to double click, so sometimes we do not
+	// have the context set here ...
+	if(!m_contextState)
+		m_contextState = pView->getMouseContext(x,y);
+	
 	EV_EditMouseContext emc = m_contextState;
+	
 	m_clickState = EV_EMO_DOUBLECLICK;
 
 	result = m_pEEM->Mouse(emc|EV_EMO_DOUBLECLICK|emb|ems, &pEM);
@@ -303,4 +306,4 @@ void EV_Win32Mouse::onButtonWheel(AV_View * pView, HWND hWnd, EV_EditMouseButton
 	default:		
 		return;
 	}
-}
\ No newline at end of file
+}
