@@ -21,6 +21,7 @@
 #define GR_QNXIMAGE_H
 
 #include "gr_Image.h"
+#include <Pt.h>
 
 struct Fatmap
 {
@@ -35,13 +36,14 @@ class GR_QNXImage : public GR_RasterImage
 {
 public:
 	GR_QNXImage(const char* pszName);
-	~GR_QNXImage();
+	virtual ~GR_QNXImage();
 
 	virtual UT_sint32	getDisplayWidth(void) const;
 	virtual UT_sint32	getDisplayHeight(void) const;
 	virtual bool		convertToBuffer(UT_ByteBuf** ppBB) const;
 	virtual bool		convertFromBuffer(const UT_ByteBuf* pBB, UT_sint32 iDisplayWidth, UT_sint32 iDisplayHeight);
-
+	virtual void		scaleImageTo(GR_Graphics *pG,const UT_Rect &rec);
+	virtual GR_Image *	createImageSegment(GR_Graphics *pG,const UT_Rect &);
    	void			setData(PhImage_t * image) { m_image = image; }
 	PhImage_t *			getData(void) const { return m_image; }
 
