@@ -61,6 +61,10 @@ void GR_Win32CharWidths::setCharWidthsOfRange(HDC hdc, UT_UCSChar c0, UT_UCSChar
 			else
 			{
 				GetCharWidth32W(hdc,k,k,&w);
+#ifdef DEBUG
+				ABC abc;
+				int iRes = GetCharABCWidthsW(hdc,k,k,&abc);
+#endif
 				// handle overstriking chars here
 				UT_uint32 iOver = UT_isOverstrikingChar(k);
 				if(!w || iOver != UT_NOT_OVERSTRIKING)
@@ -410,7 +414,7 @@ void GR_Win32CharWidths::_retrieveFontInfo(HDC hdc)
 #ifdef DEBUG
 	for(UT_uint32 n = 0; n < m_vRanges.getItemCount() - 1; n += 2)
 	{
-		UT_DEBUGMSG(("GR_Win32CharWidths::_retrieveFontInfo: range 0x%04x - 0x%04x\n",
+		xxx_UT_DEBUGMSG(("GR_Win32CharWidths::_retrieveFontInfo: range 0x%04x - 0x%04x\n",
 					 m_vRanges.getNthItem(n), m_vRanges.getNthItem(n+1)));
 	}
 	
