@@ -653,64 +653,35 @@ const char * UT_pathSuffix(const char * path)
 	}
 }
 
-typedef struct {
-  UT_UCSChar low;
-  UT_UCSChar high; 
-} ucs_range;
-
-static ucs_range s_word_delim[] = 
-{
-  // we will include all control chars from Latin1
-  {0x0001, 0x0021},
-  {0x0023, 0x0026},
-  {0x0028, 0x002f},
-  {0x003a, 0x0040},
-  {0x005b, 0x0060},
-  {0x007b, 0x007e},
-  {0x00a1, 0x00a7},
-  {0x00a9, 0x00b3},
-  {0x00b5, 0x00b6},
-  {0x00b9, 0x00bf},
-  {0x00f7, 0x00f7},
-  {0x060c, 0x060c}, //Arabic punctuation
-  {0x061b, 0x061b},
-  {0x061f, 0x061f},
-  {0xfeff, 0xfeff}
-};
-
-static bool s_find_delim(UT_UCSChar c)
-{
-    // This function is called for every character in the document
-    // during spell-checking. So make an effort to return in a hurry,
-    // by checking for the common cases (a-z and the biggest area)
-    // first. (not A-Z since there are more word seperators than
-    // capitals in a sentence!)
-    if ('a' <= c && c <= 'z') return false;
-    if (0x00f8 <= c && c <= 0xfefe) return false;
-
-    // Everything else via the table above...
-    for(UT_uint32 i = 0; i < NrElements(s_word_delim); i++)
-	{
-		if(c < s_word_delim[i].low)
-			return false;
-
-		if(c <= s_word_delim[i].high)
-			return true;
-	}
-	return false;
-}
 
 bool UT_isWordDelimiter(UT_UCSChar currentChar, UT_UCSChar followChar, UT_UCSChar prevChar)
 {
 #if 1
+	// fast track Ascii letters
+	if('a' <= currentChar && currentChar <= 'z')
+		return false;
+
+	if('A' <= currentChar && currentChar <= 'Z')
+		return false;
+	
     switch(currentChar)
 	{
+		case 0xb7:	// Catalan middledot, like instal·lació
+			return false;
+		case ',':
+		case '.':
+			if(UT_UCS4_isdigit(followChar) && UT_UCS4_isdigit(prevChar))
+				return false;
+			else
+				return true;
+			
 		case '"': //in some languages this can be in the middle of a word (Hebrew)
 		case '\'':	// we want quotes inside words for contractions
 		case UCS_LDBLQUOTE:    // smart quote, open double /* wjc */
 		case UCS_RDBLQUOTE:    // smart quote, close double /* wjc */
 		case UCS_LQUOTE:    // smart quote, open single  /* wjc */
 		case UCS_RQUOTE:	// we want quotes inside words for contractions
+		case '-':
 			if (UT_UCS4_isalpha(followChar) && UT_UCS4_isalpha(prevChar))
 			  {
 				  return false;
@@ -723,7 +694,13 @@ bool UT_isWordDelimiter(UT_UCSChar currentChar, UT_UCSChar followChar, UT_UCSCha
 			return true;
 
 		default:
-			return s_find_delim(currentChar);
+			{
+				UT_BidiCharType t = UT_bidiGetCharType(currentChar);
+				if(UT_BIDI_IS_NSM(t) || UT_BIDI_IS_LETTER(t))
+					return false;
+				else
+					return true;
+			}
 	}
 
 #else
@@ -802,7 +779,7 @@ bool UT_isWordDelimiter(UT_UCSChar currentChar, UT_UCSChar followChar, UT_UCSCha
 
 const XML_Char* UT_getAttribute(const XML_Char* name, const XML_Char** atts)
 {
-	UT_ASSERT(atts);
+	UT_return_val_if_fail( atts, NULL );
 
 	const XML_Char** p = atts;
 
@@ -852,10 +829,10 @@ UT_sint32 signedHiWord(UT_uint32 dw)
  * string in the vector will contain the remainder of the original string 
  * (str).
  */
-UT_Vector * simpleSplit (const UT_String & str, char separator,
+UT_GenericVector<UT_String*> * simpleSplit (const UT_String & str, char separator,
 						 size_t max)
 {
-	UT_Vector * utvResult = new UT_Vector();
+	UT_GenericVector<UT_String*> * utvResult = new UT_GenericVector<UT_String*>();
 	UT_String* utsEntry;
 	UT_uint32 start = 0;
 
@@ -1067,3 +1044,179 @@ bool UT_parseBool (const char * param, bool dfl)
 	
 	return dfl;
 }
+
+const UT_UTF8String & UT_VersionInfo::getString() const
+{
+	static UT_UTF8String vers = UT_UTF8String_sprintf("%d.%d.%d.%d", 
+													  m_iMajor, m_iMinor, 
+													  m_iMicro, m_iNano);
+	return vers;
+}
+
+
+const XML_Char ** UT_setPropsToNothing(const XML_Char ** props)
+{
+	if(!props)
+		return NULL;
+	
+	const XML_Char ** props2;
+
+	UT_uint32 iCount  = 0;
+									
+	while(props[iCount])
+		iCount += 2;
+
+									
+	props2 = new const XML_Char * [iCount+1];
+
+	UT_uint32 i;
+	for(i = 0; i < iCount; i += 2)
+	{
+		props2[i] = props[i];
+		props2[i+1] = NULL;
+	}
+
+	props2[i] = NULL;
+
+	return props2;
+}
+
+const XML_Char ** UT_setPropsToValue(const XML_Char ** props, const XML_Char * value)
+{
+	if(!props)
+		return NULL;
+	
+	const XML_Char ** props2;
+
+	UT_uint32 iCount  = 0;
+									
+	while(props[iCount])
+		iCount += 2;
+
+									
+	props2 = new const XML_Char * [iCount+1];
+
+	UT_uint32 i;
+	for(i = 0; i < iCount; i += 2)
+	{
+		props2[i] = props[i];
+		props2[i+1] = value;
+	}
+
+	props2[i] = NULL;
+
+	return props2;
+}
+
+/*!
+   splits the xml property string (font-size:24pt;font-face:Arial') into names and values
+   and stores them in an array
+
+   the caller has to delete[] the array; the process is destructive to props
+*/
+const XML_Char ** UT_splitPropsToArray(XML_Char * pProps)
+{
+		UT_return_val_if_fail( pProps, NULL);
+	
+		UT_uint32 iLen = strlen(pProps);
+	
+		UT_uint32 i = 1; // *props != 0 => at least one
+		if(pProps[iLen-1] == ';')
+		{
+			// trailing ;
+			--i;
+		}
+
+		char * semi = NULL;
+		const char * p = pProps;
+		while(semi = strchr(p, ';'))
+		{
+			*semi = 0;
+			p = semi + 1;
+			i++;
+		}
+	
+	
+		UT_uint32 iPropCount = i;
+		UT_uint32 j = 0;
+		const XML_Char ** pPropsArray = new const XML_Char *[2 * iPropCount + 1];
+		UT_return_val_if_fail( pPropsArray, NULL );
+	
+		const char * pStart = pProps;
+
+		// we want to include the 0-terminator
+		for(i = 0; i <= iLen; i++)
+		{
+			if(pProps[i] == 0)
+			{
+				pPropsArray[j++] = pStart;
+				char * colon = strchr(pStart, ':');
+				UT_return_val_if_fail( colon,NULL );
+				*colon = 0;
+				pPropsArray[j++] = colon + 1;
+
+				if(i == iLen)
+					break;
+				
+				pStart = pProps + i + 1;
+				while(isspace(*pStart))
+					pStart++;
+			}
+		}
+	
+		UT_return_val_if_fail( j == 2 * iPropCount, NULL );
+
+		pPropsArray[j] = NULL;
+		return pPropsArray;
+}
+
+
+#if defined(WIN32) && !defined(__GNUC__)	
+#   define MYZERO 0
+#else
+#   define MYZERO 0LL
+#endif
+
+UT_uint64 UT_hash64(const char * p, UT_uint32 bytelen)
+{
+	UT_return_val_if_fail( p, MYZERO );
+	
+	if(!bytelen)
+	{
+		bytelen = strlen(p);
+	}
+
+	UT_return_val_if_fail( bytelen, MYZERO );
+	
+	UT_uint64 h = (UT_uint64)*p;
+	
+	for (UT_uint32 i = 1; i < bytelen; ++i, ++p)
+	{
+		h = (h << 5) - h + *p;
+	}
+
+	return h;
+}
+
+UT_uint32 UT_hash32(const char * p, UT_uint32 bytelen)
+{
+	UT_return_val_if_fail( p, 0 );
+	
+	if(!bytelen)
+	{
+		bytelen = strlen(p);
+	}
+
+	UT_return_val_if_fail( bytelen, 0 );
+
+	UT_uint32 h = (UT_uint32)*p;
+	
+	for (UT_uint32 i = 1; i < bytelen; ++i, ++p)
+	{
+		h = (h << 5) - h + *p;
+	}
+
+	return h;
+}
+
+#undef MYZERO
