@@ -93,20 +93,40 @@ static void _cdata (void * userData, const XML_Char * buffer, int length)
   pXML->cdataSection (false);
 }
 
-static void _errorSAXFunc(void *ctx,
+static void _errorSAXFunc(void *xmlp,
 			  const char *msg,
 			  ...)
 {
   va_list args;
   va_start (args, msg);
-  UT_String errorMessage(UT_String_vprintf (msg, args));
+  UT_String errorMessage;
+  UT_String_vprintf (errorMessage,msg, args);
   va_end (args);
-  UT_DEBUGMSG(("SAX function error here \n"));
-  UT_DEBUGMSG(("%s", errorMessage.c_str()));
-  UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+  // Handle 'nbsp' here
+  UT_XML * pXML = reinterpret_cast<UT_XML *>(xmlp);
+  pXML->incMinorErrors();
+  char * szErr = UT_strdup(errorMessage.c_str() );
+  if(strstr(szErr,"'nbsp' not defined") != NULL)
+  {
+    UT_DEBUGMSG(("nbsp found in stream errs %d \n",pXML->getNumMinorErrors()));
+      pXML->incRecoveredErrors();
+      const char buffer []= {0xa0};
+      pXML->charData(buffer,1); 
+  }
+  else if(strstr(szErr,"not defined") != NULL)
+  {
+      pXML->incRecoveredErrors();
+  }
+  else
+  {
+      UT_DEBUGMSG(("SAX function error here \n"));
+      UT_DEBUGMSG(("%s", errorMessage.c_str()));
+      UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+  }
+  FREEP(szErr);
 }
 
-static void _fatalErrorSAXFunc(void *ctx,
+static void _fatalErrorSAXFunc(void *xmlp,
 			       const char *msg,
 			       ...)
 {
@@ -117,8 +137,7 @@ static void _fatalErrorSAXFunc(void *ctx,
   UT_DEBUGMSG((" fatal SAX function error here \n"));
 
   UT_DEBUGMSG(("%s", errorMessage.c_str()));
-  xmlParserCtxt * pCtx = reinterpret_cast<xmlParserCtxt *>(ctx);
-  UT_XML * pXML = static_cast<UT_XML *>(pCtx->userData);
+  UT_XML * pXML = reinterpret_cast<UT_XML *>(xmlp);
   UT_DEBUGMSG((" userData pointer is %x \n",pXML));
   UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
   pXML->stop();
@@ -192,25 +211,29 @@ UT_Error UT_XML::parse (const char * szFilename)
 			
 			if (xmlParseChunk (ctxt, buffer, static_cast<int>(length), 0))
 			{
-				UT_DEBUGMSG (("Error parsing '%s' (Line: %d, Column: %d)\n", szFilename, getLineNumber(ctxt), getColumnNumber(ctxt)));
+			  if(getNumMinorErrors() > getNumRecoveredErrors())
+			    {
+				UT_DEBUGMSG (("Error - 1 parsing '%s' (Line: %d, Column: %d)\n", szFilename, getLineNumber(ctxt), getColumnNumber(ctxt)));
 				ret = UT_IE_IMPORTERROR;
 				break;
+			    }
 			}
 		}
 		if (ret == UT_OK)
-			if (!m_bStopped)
+		  if (!m_bStopped && (getNumMinorErrors() == 0))
 			{
 				if (xmlParseChunk (ctxt, "", 0, 1))
 				{
-					UT_DEBUGMSG (("Error parsing '%s' (Line: %d, Column: %d)\n", szFilename, getLineNumber(ctxt), getColumnNumber(ctxt)));
+					UT_DEBUGMSG (("Error -2 parsing '%s' (Line: %d, Column: %d)\n", szFilename, getLineNumber(ctxt), getColumnNumber(ctxt)));
 					ret = UT_IE_IMPORTERROR;
 				}
 			}
-		if (ret == UT_OK)
+		if (ret == UT_OK && (getNumMinorErrors() == 0))
 			if (!ctxt->wellFormed && !m_bStopped) ret = UT_IE_IMPORTERROR; // How does stopping mid-file affect wellFormed?
-		
-		ctxt->sax = NULL;
+
+		xmlDocPtr xmlDoc = ctxt->myDoc;
 		xmlFreeParserCtxt (ctxt);
+		xmlFreeDoc(xmlDoc);
     }
 	else
     {
@@ -237,9 +260,9 @@ UT_Error UT_XML::parse (const char * buffer, UT_uint32 length)
 
   UT_Error ret = UT_OK;
 
-  xmlSAXHandler hdl;
   xmlParserCtxtPtr ctxt;
 
+  xmlSAXHandler hdl;
   memset(&hdl, 0, sizeof(hdl));
 
   hdl.getEntity    = _getEntity;
@@ -258,7 +281,7 @@ UT_Error UT_XML::parse (const char * buffer, UT_uint32 length)
       UT_DEBUGMSG (("Unable to create libxml2 memory context!\n"));
       return UT_ERROR;
     }
-  ctxt->sax = &hdl;
+  memcpy(ctxt->sax, &hdl, sizeof(hdl));
   ctxt->userData = static_cast<void *>(this);
 
   m_bStopped = false;
@@ -267,8 +290,24 @@ UT_Error UT_XML::parse (const char * buffer, UT_uint32 length)
 
   if (!ctxt->wellFormed) ret = UT_IE_IMPORTERROR;
 
-  ctxt->sax = NULL;
+  xmlDocPtr xmlDoc = ctxt->myDoc;
   xmlFreeParserCtxt (ctxt);
+  xmlFreeDoc(xmlDoc);
 
   return ret;
 }
+
+// guardian because (afaik) xmlParserXXX aren't guaranteed to be idempotent
+static volatile int iLibXml2Guardian = 0;
+
+void UT_XML::_init()
+{
+  if(++iLibXml2Guardian == 1)
+    xmlInitParser();
+}
+
+void UT_XML::_cleanup()
+{
+  if(--iLibXml2Guardian == 0)
+    xmlCleanupParser();
+}
