@@ -20,7 +20,7 @@
 #ifndef XAP_UNIXDIALOG_MESSAGEBOX_H
 #define XAP_UNIXDIALOG_MESSAGEBOX_H
 
-#include "xap_UnixFrame.h"
+#include "xap_Frame.h"
 #include "xap_Dlg_MessageBox.h"
 #include <glib.h>
 class XAP_UnixFrame;
@@ -37,22 +37,7 @@ public:
 
 	static XAP_Dialog *		static_constructor(XAP_DialogFactory *, XAP_Dialog_Id id);
 
-	// must let static callbacks read our bindings
-	UT_Vector * 		_getBindingsVector();
-	void 				_setAnswer(XAP_Dialog_MessageBox::tAnswer answer);
-		
-	// Export for use by s_key_pressed()
-   	struct keyBinding
-	{
-		guint key;
-		XAP_Dialog_MessageBox::tAnswer answer;
-	};
-
 protected:
-	XAP_UnixFrame *			m_pUnixFrame;
-	UT_Vector 				m_keyBindings;
-
-	void _bindKey(guint key, XAP_Dialog_MessageBox::tAnswer answer);
 	
 };
 
