@@ -242,21 +242,23 @@ XAP_Module * XAP_App::getPlugin(const char * szPluginName)
  */
 UT_uint32 XAP_App::registerEmbeddable(GR_EmbedManager * pEmbed)
 {
+	 UT_return_val_if_fail( pEmbed, 0xFFFFFFF );
+	 
      UT_sint32 i=0;
      bool bFound = false;
      GR_EmbedManager * pCur = NULL;
      for(i=0; !bFound && (i< static_cast<UT_sint32>(m_vecEmbedManagers.getItemCount())); i++)
      {
-       pCur =  m_vecEmbedManagers.getNthItem(i);
-       if(UT_strcmp(pCur->getObjectType(),pEmbed->getObjectType()) == 0)
-       {
-	 bFound = true;
-       }
+		 pCur =  m_vecEmbedManagers.getNthItem(i);
+		 if(UT_strcmp(pCur->getObjectType(),pEmbed->getObjectType()) == 0)
+		 {
+			 bFound = true;
+		 }
      }
      if(!bFound)
      {
-       m_vecEmbedManagers.addItem(pEmbed);
-       return  m_vecEmbedManagers.getItemCount() - 1;
+		 m_vecEmbedManagers.addItem(pEmbed);
+		 return  m_vecEmbedManagers.getItemCount() - 1;
      }
      return 0xFFFFFFF;
 }
