@@ -31,6 +31,23 @@
 #include "xap_Frame.h"
 #include "xap_Dialog.h"
 
+typedef enum _WRAPPING_TYPE
+{
+    WRAP_INLINE,
+    WRAP_TEXTRIGHT,
+    WRAP_TEXTLEFT,
+    WRAP_TEXTBOTH,
+    WRAP_NONE
+} WRAPPING_TYPE;
+
+
+typedef enum _POSITION_TO
+{
+    POSITION_TO_PARAGRAPH,
+    POSITION_TO_COLUMN,
+    POSITION_TO_PAGE
+} POSITION_TO;
+
 /* #include "xav_View.h" */
 
 
@@ -45,6 +62,18 @@ public:
 
 	virtual void  runModal(XAP_Frame * pFrame) = 0;
 
+	void setWrapping(WRAPPING_TYPE iWrap);
+	void setPositionTo(POSITION_TO iPos);
+	bool isInHdrFtr(void);
+	void setInHdrFtr(bool b)
+	  { m_bInHdrFtr = b;}
+
+	WRAPPING_TYPE getWrapping(void) const
+		{ return m_iWrappingType;}
+	POSITION_TO getPositionTo(void) const
+		{ return m_iPositionTo;}
+
+
 	double getWidth () const { return m_width; }
 	double getHeight () const { return m_height; }
 	bool getPreserveAspect() const { return m_bAspect; }
@@ -59,8 +88,8 @@ public:
 	void setWidth (UT_sint32 w);
 	void setHeight (UT_sint32 h);
 
-	void setMaxHeight ( double h ) { m_maxWidth = h; }
-	void setMaxWidth ( double w ) { m_maxHeight = w; }
+	void setMaxHeight ( double h ) { m_maxHeight = h; }
+	void setMaxWidth ( double w ) { m_maxWidth = w; }
 
 	double getMaxWidth () const { return m_maxWidth; }
 	double getMaxHeight () const { return m_maxHeight; }
@@ -75,6 +104,26 @@ public:
 	void setWidth(const char * szWidth);
 	UT_Dimension getPreferedUnits(void);
 	void  setPreferedUnits(UT_Dimension dim);
+	void setTightWrap(bool bTight)
+	  { m_bTightWrap = bTight;}
+	bool isTightWrap(void)
+	  { return m_bTightWrap;}
+	void setTitle(const UT_UTF8String & title) {
+		m_title = title;
+	}
+
+	const UT_UTF8String & getTitle() const {
+		return m_title;
+	}
+
+	void setDescription(const UT_UTF8String & description) {
+		m_description = description;
+	}
+
+	const UT_UTF8String & getDescription() const {
+		return m_description;
+	}
+
 
  protected:	  
 	void setAnswer ( tAnswer ans ) { m_answer = ans; }
@@ -93,8 +142,16 @@ public:
 	bool m_bWidthChanged;
 	UT_Dimension m_PreferedUnits;
 
+	UT_UTF8String m_title;
+	UT_UTF8String m_description;
+
 	void setWidth (double w, bool checkaspect);
 	void setHeight (double h, bool checkaspect);
+
+	WRAPPING_TYPE m_iWrappingType;
+	POSITION_TO m_iPositionTo;
+	bool m_bInHdrFtr;
+	bool m_bTightWrap;
 };
 
 #endif /* XAP_DIALOG_IMAGE_H */
