@@ -21,11 +21,17 @@
 #ifndef FG_GRAPHIC_H
 #define FG_GRAPHIC_H
 
-#include "fl_Layout.h"
-#include "px_CR_Object.h"
-#include "gr_Graphics.h"
-#include "gr_Image.h"
 #include "ut_types.h"
+#include "pt_Types.h"
+
+class fl_ContainerLayout;
+class PX_ChangeRecord_Object;
+class PP_AttrProp;
+class PD_Document;
+class GR_Graphics;
+class GR_Image;
+
+
 
 enum FGType { 
 	FGT_Unknown,
@@ -41,8 +47,9 @@ enum FGType {
 class ABI_EXPORT FG_Graphic
 {
 public:
-	static FG_Graphic*	createFromChangeRecord(const fl_Layout *pFL,
+	static FG_Graphic*	createFromChangeRecord(const fl_ContainerLayout *pFL,
 											   const PX_ChangeRecord_Object* pcro);
+	static FG_Graphic*	createFromStrux(const fl_ContainerLayout *pFL);
 
 	virtual ~FG_Graphic();
 
@@ -58,7 +65,8 @@ public:
 //
 	virtual const char * getWidthProp(void) = 0;
 	virtual const char * getHeightProp(void) = 0;
-
+	virtual GR_Image *     regenerateImage(GR_Graphics * pG) = 0;
+	virtual FG_Graphic *   clone(void) = 0;
 	//  generate an image for display in the specified graphics object
 	virtual GR_Image* generateImage(GR_Graphics* pG,
 								   const PP_AttrProp * pSpanAP,
@@ -67,6 +75,12 @@ public:
 	//  Insert the object at the specified point in a document
 	virtual UT_Error   	insertIntoDocument(PD_Document* pDoc, UT_uint32 res,
 										   UT_uint32 iPos, const char* szName) = 0;
+	//  Attach the object to a strux for a background image for the strux
+	virtual UT_Error   	insertAtStrux(PD_Document* pDoc, 
+									  UT_uint32 res,
+									  UT_uint32 iPos,
+									  PTStruxType iStruxType, 
+									  const char* szName) = 0;
 };
 
 #endif /* FG_GRAPHIC_H */
