@@ -91,7 +91,7 @@ void __dump_sq(void)
 	{
 		fl_PartOfBlock* pPOB = FL_DocLayout::m_pDocLayout->getPendingWordForSpell();
 		fprintf(stdout, "Pending word: %p [%d:%d]\n", (void*)pPOB,
-				pPOB->getOffset(), pPOB->getOffset()+pPOB->getLength());
+				pPOB->getOffset(), pPOB->getOffset()+pPOB->getPTLength());
 	}
 	else
 	{
@@ -103,7 +103,7 @@ void __dump_sq(void)
 	{
 		fprintf(stdout,"Section: %p [type %d]\n",(void*)psl,psl->getType());
 		for (fl_BlockLayout * pBL=(fl_BlockLayout *) psl->getFirstLayout(); (pBL); pBL= (fl_BlockLayout *) pBL->getNext())
-			pBL->getSquiggles()->__dump(stdout);
+			pBL->getSpellSquiggles()->__dump(stdout);
 	}
 }
 
@@ -244,7 +244,7 @@ void fl_Squiggles::__dump(FILE * fp) const
 	{
 		pPOB = getNth(j);
 		fprintf(fp, "  %d: [%d:%d]\n", j, pPOB->getOffset(),
-				pPOB->getOffset() + pPOB->getLength());
+				pPOB->getOffset() + pPOB->getPTLength());
 	}
 }
 #endif
