@@ -195,11 +195,13 @@ static GtkBinClass * parent_class = 0;
 
 static void s_abi_widget_map_cb(GObject * w,  GdkEvent *event,gpointer p);
 
+#if 0
 static void s_abi_widget_destroy(GObject * w, gpointer abi);
 
 static void s_abi_widget_delete(GObject * w, gpointer abi);
 
 static void abi_widget_destroy (GObject *object);
+#endif
 
 /**************************************************************************/
 /**************************************************************************/
@@ -466,9 +468,9 @@ static void s_LoadingCursorCallback(UT_Worker * pTimer )
 
 /*!
  * Control Method for the updating loader.
-\params bool bStartStop true to start the updating loader, flase to stop it
+\param bool bStartStop true to start the updating loader, flase to stop it
              after the document has loaded.
-\params XAP_Frame * pFrame Pointer to the new frame being loaded.
+\param XAP_Frame * pFrame Pointer to the new frame being loaded.
 */
 static void s_StartStopLoadingCursor( bool bStartStop, XAP_Frame * pFrame)
 {
@@ -547,7 +549,7 @@ abi_widget_load_file(AbiWidget * abi, const char * pszFile)
 //
 //Now load the file
 //
-	bool res= ( UT_OK == pFrame->loadDocument(abi->priv->m_szFilename,IEFT_Unknown ,true));
+	/*bool res=*/ ( UT_OK == pFrame->loadDocument(abi->priv->m_szFilename,IEFT_Unknown ,true));
 	s_StartStopLoadingCursor( false, pFrame);
 	abi->priv->m_bPendingFile = false;
 	abi->priv->m_iNumFileLoads += 1;
@@ -592,6 +594,7 @@ static void s_abi_widget_map_cb(GObject * w,  GdkEvent *event,gpointer p)
 }
 
 
+#if 0
 static void s_abi_widget_destroy(GObject * w, gpointer p)
 {
 
@@ -611,6 +614,7 @@ static void s_abi_widget_delete(GObject * w, gpointer p)
 
   abi_widget_destroy(G_OBJECT(p));
 }
+#endif
 
 //
 // arguments to abiwidget
@@ -1326,6 +1330,7 @@ abi_widget_realize (GtkWidget * widget)
 }
 
 #ifdef HAVE_GNOME
+#if 0
 static void
 abi_widget_finalize(GObject *object)
 {
@@ -1364,9 +1369,10 @@ abi_widget_finalize(GObject *object)
 	BONOBO_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 #endif
+#endif
 
 
-
+#if 0
 static void
 abi_widget_destroy (GObject *object)
 {
@@ -1403,6 +1409,7 @@ abi_widget_destroy (GObject *object)
 	fprintf(getlogfile(),"abiwidget destroyed in abi_widget_destroy \n");
 #endif
 }
+#endif
 
 
 static void
