@@ -1258,11 +1258,12 @@ int AP_Win32App::WinMain(const char * szAppName, HINSTANCE hInstance,
 	// process args (calls common arg handler, which then calls platform specific)
 	// As best I understand, it returns true to continue and show window, or
 	// false if no window should be shown (and thus we should simply exit).
-	if (!Args.doWindowlessArgs())
+	bool windowlessArgsWereSuccessful = true;
+	if (!Args.doWindowlessArgs(windowlessArgsWereSuccessful))
 	{
 		pMyWin32App->shutdown();	// properly shutdown the app 1st
 		delete pMyWin32App;
-		return 0;
+		return (windowlessArgsWereSuccessful ? 0 : -1);
 	}
 
 	// Step 3: Create windows as appropriate.
@@ -1387,7 +1388,7 @@ catch (...)
 	
 	UT_uint32 i = 0;
 	
-	IEFileType abiType = IE_Imp::fileTypeForSuffix("abw");
+	IEFileType abiType = IE_Imp::fileTypeForSuffix(".abw");
 	for(;i<pApp->m_vecFrames.getItemCount();i++)
 	{
 		AP_Win32Frame * curFrame = (AP_Win32Frame*)pApp->m_vecFrames[i];
@@ -1507,8 +1508,10 @@ void AP_Win32App::errorMsgBadFile(XAP_Frame * pFrame, const char * file,
  * platform-specific windowless args.
  * return false if we should exit normally but Window should not be displayed
  */
-bool AP_Win32App::doWindowlessArgs(const AP_Args *Args)
+bool AP_Win32App::doWindowlessArgs(const AP_Args *Args, bool & bSuccess)
 {
+	bSuccess = true;
+
 	AP_Win32App * pMyWin32App = static_cast<AP_Win32App*>(Args->getApp());
 
 	if (Args->m_sGeometry)
@@ -1556,7 +1559,7 @@ bool AP_Win32App::doWindowlessArgs(const AP_Args *Args)
 			}
 			
 			conv.setVerbose(Args->m_iVerbose);
-			conv.print (Args->m_sFile, pG);
+			conv.print (Args->m_sFile, pG, Args->m_sFileExtension);
 	      
 			delete pG;
 		}
@@ -1564,6 +1567,7 @@ bool AP_Win32App::doWindowlessArgs(const AP_Args *Args)
 		{
 			// couldn't load document
 			printf("Error: no file to print!\n");
+			bSuccess = false;
 		}
 
 		return false;
@@ -1592,6 +1596,7 @@ bool AP_Win32App::doWindowlessArgs(const AP_Args *Args)
 		if(!bFound)
 		{
 			printf("Plugin %s not found or loaded \n",Args->m_sPlugin);
+			bSuccess = false;
 			return false;
 		}
 
@@ -1606,6 +1611,7 @@ bool AP_Win32App::doWindowlessArgs(const AP_Args *Args)
 		{
 			printf("Plugin %s invoke method %s not found \n",
 				   Args->m_sPlugin,evExecute);
+			bSuccess = false;
 			return false;
 		}
 		//
