@@ -18,6 +18,7 @@
  * 02111-1307, USA.
  */
 
+#include "ap_Features.h"
 #include "ap_App.h"
 #include "ap_Args.h"
 #include "ap_Prefs_SchemeIds.h"
@@ -132,7 +133,7 @@ void AP_App::errorMsgBadFile(XAP_Frame *, const char *, UT_Error)
 	UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
 }
 
-bool AP_App::doWindowlessArgs (const AP_Args *)
+bool AP_App::doWindowlessArgs (const AP_Args *, bool & bSuccess)
 {
 	return false;
 }
