@@ -1,3 +1,5 @@
+/* -*- mode: C++; tab-width: 4; c-basic-offset: 4; -*- */
+
 /* AbiWord
  * Copyright (C) 1998 AbiSource, Inc.
  * 
@@ -20,10 +22,14 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
+
+#include "ap_Features.h"
+
 #include "ut_assert.h"
 #include "ut_string.h"
 #include "ut_debugmsg.h"
 
+#include "xap_App.h"
 #include "xap_Dialog_Id.h"
 #include "xap_DialogFactory.h"
 #include "xap_Dlg_MessageBox.h"
@@ -109,28 +115,37 @@ void AP_Dialog_MergeCells::stopUpdater(void)
 	DELETEP(m_pAutoUpdaterMC);
 	m_pAutoUpdaterMC = NULL;
 }
+
 /*!
  * Autoupdater of the dialog.
  */
 void AP_Dialog_MergeCells::autoUpdateMC(UT_Worker * pTimer)
 {
-
-	UT_ASSERT(pTimer);
+	UT_return_if_fail(pTimer);
 	
 // this is a static callback method and does not have a 'this' pointer
 
 	AP_Dialog_MergeCells * pDialog = static_cast<AP_Dialog_MergeCells *>(pTimer->getInstanceData());
-	// Handshaking code
-	FV_View * pView = static_cast<FV_View *>(pDialog->getApp()->getLastFocussedFrame()->getCurrentView());
-	PD_Document * pDoc = pView->getDocument();
-	if( pDialog->m_bDestroy_says_stopupdating != true)
+
+	if (pDialog->m_bDestroy_says_stopupdating != true)
 	{
-		pDialog->m_bAutoUpdate_happening_now = true;
-		if(!pDoc->isPieceTableChanging())
+		FV_View * pView = 0;
+
+		if (XAP_Frame * pFrame = pDialog->getApp()->getLastFocussedFrame())
 		{
-			pDialog->setAllSensitivities();
+			pView = static_cast<FV_View *>(pFrame->getCurrentView());
+		}
+		if (pView)
+		{
+			PD_Document * pDoc = pView->getDocument();
+
+			if (!pDoc->isPieceTableChanging())
+			{
+				pDialog->m_bAutoUpdate_happening_now = true;
+				pDialog->setAllSensitivities();
+				pDialog->m_bAutoUpdate_happening_now = false;
+			}
 		}
-		pDialog->m_bAutoUpdate_happening_now = false;
 	}
 }        
 
@@ -142,16 +157,29 @@ void AP_Dialog_MergeCells::autoUpdateMC(UT_Worker * pTimer)
  */
 void AP_Dialog_MergeCells::setAllSensitivities(void)
 {
-    FV_View * pView = static_cast<FV_View *>(m_pApp->getLastFocussedFrame()->getCurrentView());
-	m_iCellSource = pView->getPoint();
-	if(!pView->isInTable())
+	FV_View * pView = 0;
+
+	if (XAP_Frame * pFrame = getApp()->getLastFocussedFrame())
 	{
-		setSensitivity(radio_above,false);
-		setSensitivity(radio_below,false);
-		setSensitivity(radio_left,false);
-		setSensitivity(radio_right,false);
+		pView = static_cast<FV_View *>(pFrame->getCurrentView());
+	}
+	if (!pView)
+	{
+		setSensitivity(radio_left,  false);
+		setSensitivity(radio_right, false);
+		setSensitivity(radio_above, false);
+		setSensitivity(radio_below, false);
 		return;
 	}
+	if (!pView->isInTable())
+	{
+		setSensitivity(radio_left,  false);
+		setSensitivity(radio_right, false);
+		setSensitivity(radio_above, false);
+		setSensitivity(radio_below, false);
+		return;
+	}
+
 	PT_DocPosition iCurPos = pView->getPoint();
 	m_iCellSource = iCurPos;
 	pView->getCellParams(iCurPos,&m_iLeft,&m_iRight,&m_iTop,&m_iBot);
@@ -174,7 +202,15 @@ void AP_Dialog_MergeCells::setAllSensitivities(void)
 
 	fp_Container * pCon = pLine->getContainer();
 	UT_return_if_fail(pCon);
-
+	if(pCon->getContainerType() != FP_CONTAINER_CELL)
+	{
+		UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+		setSensitivity(radio_above,false);
+		setSensitivity(radio_below,false);
+		setSensitivity(radio_left,false);
+		setSensitivity(radio_right,false);
+		return;
+	}
 	fp_TableContainer * pTab = static_cast<fp_TableContainer *>(pCon->getContainer());
 	UT_return_if_fail(pTab);
 	UT_return_if_fail(pTab->getContainerType() == FP_CONTAINER_TABLE);
@@ -269,9 +305,17 @@ void AP_Dialog_MergeCells::_generateSrcDest(void)
  */
 void AP_Dialog_MergeCells::onMerge(void)
 {
-	_generateSrcDest();
-	FV_View * pView = static_cast<FV_View *>(m_pApp->getLastFocussedFrame()->getCurrentView());
-	pView->cmdMergeCells(m_iCellSource, m_iCellDestination);
+	FV_View * pView = 0;
+
+	if (XAP_Frame * pFrame = getApp()->getLastFocussedFrame())
+	{
+		pView = static_cast<FV_View *>(pFrame->getCurrentView());
+	}
+	if (pView)
+	{
+		_generateSrcDest();
+		pView->cmdMergeCells(m_iCellSource, m_iCellDestination);
+	}
 	setAllSensitivities();
 }
 
