@@ -35,7 +35,10 @@ BeginLayout(Main,0)
 		MenuItem(AP_MENU_ID_FILE_NEW)
 		MenuItem(AP_MENU_ID_FILE_NEW_USING_TEMPLATE)
 		MenuItem(AP_MENU_ID_FILE_OPEN)
+	
+#if !XP_SIMPLE_MENU	
 		MenuItem(AP_MENU_ID_FILE_IMPORTSTYLES)
+#endif	
 
 		Separator()
 
@@ -46,6 +49,7 @@ BeginLayout(Main,0)
 		MenuItem(AP_MENU_ID_FILE_EXPORT)
 		MenuItem(AP_MENU_ID_FILE_REVERT)
 
+#if !XP_SIMPLE_MENU
 		Separator()
 		MenuItem(AP_MENU_ID_FILE_PAGESETUP)
 #ifdef XP_UNIX_TARGET_GTK
@@ -73,9 +77,12 @@ BeginLayout(Main,0)
 			MenuItem(AP_MENU_ID_FILE_RECENT_8)
 			MenuItem(AP_MENU_ID_FILE_RECENT_9)
 		EndSubMenu()
+#endif
 #endif
 		Separator()
+#if  !XP_SIMPLE_MENU
 		MenuItem(AP_MENU_ID_FILE_CLOSE)
+#endif
 		MenuItem(AP_MENU_ID_FILE_EXIT)
 	EndSubMenu()
 
@@ -86,23 +93,32 @@ BeginLayout(Main,0)
 		MenuItem(AP_MENU_ID_EDIT_CUT)
 		MenuItem(AP_MENU_ID_EDIT_COPY)
 		MenuItem(AP_MENU_ID_EDIT_PASTE)
+#if !XP_SIMPLE_MENU	
 		MenuItem(AP_MENU_ID_EDIT_PASTE_SPECIAL)
+#endif	
 		Separator()
+#if !XP_SIMPLE_MENU	
 		MenuItem(AP_MENU_ID_EDIT_CLEAR)
+#endif	
 		MenuItem(AP_MENU_ID_EDIT_SELECTALL)
 		Separator()
+#if !XP_SIMPLE_MENU	
 		MenuItem(AP_MENU_ID_EDIT_REMOVEHEADER)
 		MenuItem(AP_MENU_ID_EDIT_REMOVEFOOTER)
 		Separator()
+#endif	
 		MenuItem(AP_MENU_ID_EDIT_FIND)
 		MenuItem(AP_MENU_ID_EDIT_REPLACE)
+#if !XP_SIMPLE_MENU	
 		MenuItem(AP_MENU_ID_EDIT_GOTO)
+#endif	
 #if !(XAP_PREFSMENU_UNDER_TOOLS)
 		Separator()
 		MenuItem(AP_MENU_ID_TOOLS_OPTIONS)
 #endif
 	EndSubMenu()
 
+#if !XP_SIMPLE_MENU
 	BeginSubMenu(AP_MENU_ID_VIEW)
 		MenuItem(AP_MENU_ID_VIEW_NORMAL)
 		MenuItem(AP_MENU_ID_VIEW_WEB)
@@ -140,9 +156,9 @@ BeginLayout(Main,0)
 			MenuItem(AP_MENU_ID_VIEW_ZOOM_75)
 			MenuItem(AP_MENU_ID_VIEW_ZOOM_50)
 		EndSubMenu()
-
 	EndSubMenu()
-
+#endif /*  XP_SIMPLE_MENU */
+	
 	BeginSubMenu(AP_MENU_ID_INSERT)
 		MenuItem(AP_MENU_ID_INSERT_BREAK)
 		MenuItem(AP_MENU_ID_INSERT_PAGENO)
@@ -191,7 +207,9 @@ BeginLayout(Main,0)
 #endif
 		Separator()
 		MenuItem(AP_MENU_ID_FMT_COLUMNS)
+#if !XP_SIMPLE_MENU	
 		MenuItem(AP_MENU_ID_FMT_TABS)
+#endif	
 		MenuItem(AP_MENU_ID_FMT_HDRFTR)
 		MenuItem(AP_MENU_ID_FMT_FOOTNOTES)
 		MenuItem(AP_MENU_ID_FMT_TABLEOFCONTENTS)
@@ -224,15 +242,38 @@ BeginLayout(Main,0)
 		EndSubMenu()
 
 	    BeginSubMenu(AP_MENU_ID_FMT_DIRECTION)
+			MenuItem(AP_MENU_ID_FMT_DIRECTION_DOCD_RTL)
+			MenuItem(AP_MENU_ID_FMT_DIRECTION_SD_RTL)
 			MenuItem(AP_MENU_ID_FMT_DIRECTION_DD_RTL)
         	MenuItem(AP_MENU_ID_FMT_DIRECTION_DO_LTR)
         	MenuItem(AP_MENU_ID_FMT_DIRECTION_DO_RTL)
     	EndSubMenu()
 
+#if XP_SIMPLE_MENU
+	BeginSubMenu(AP_MENU_ID_VIEW)
+		MenuItem(AP_MENU_ID_VIEW_NORMAL)
+		MenuItem(AP_MENU_ID_VIEW_WEB)
+		MenuItem(AP_MENU_ID_VIEW_PRINT)
+		MenuItem(AP_MENU_ID_WEB_WEBPREVIEW)
+	EndSubMenu()
+	BeginSubMenu(AP_MENU_ID_VIEW_ZOOM_MENU)
+		MenuItem(AP_MENU_ID_VIEW_ZOOM)
+		MenuItem(AP_MENU_ID_VIEW_ZOOM_WIDTH)
+		MenuItem(AP_MENU_ID_VIEW_ZOOM_WHOLE)
+		MenuItem(AP_MENU_ID_VIEW_ZOOM_200)
+		MenuItem(AP_MENU_ID_VIEW_ZOOM_100)
+		MenuItem(AP_MENU_ID_VIEW_ZOOM_75)
+		MenuItem(AP_MENU_ID_VIEW_ZOOM_50)
+	EndSubMenu()
+#else	
+
 		Separator()
 
 		MenuItem(AP_MENU_ID_FMT_STYLE_DEFINE)
+	
 
+#endif
+	
 	EndSubMenu()
 
 	BeginSubMenu(AP_MENU_ID_TOOLS)
@@ -240,7 +281,9 @@ BeginLayout(Main,0)
 		MenuItem(AP_MENU_ID_TOOLS_SPELL)
 		MenuItem(AP_MENU_ID_FMT_LANGUAGE)
 		MenuItem(AP_MENU_ID_TOOLS_WORDCOUNT)
+#if !XP_SIMPLE_MENU	
         MenuItem(AP_MENU_ID_FMT_STYLIST)
+#endif	
 
 		Separator()
 
@@ -248,12 +291,16 @@ BeginLayout(Main,0)
 	        MenuItem(AP_MENU_ID_TOOLS_HISTORY_SHOW)
 	        MenuItem(AP_MENU_ID_TOOLS_REVISIONS_COMPARE_DOCUMENTS)
 		    MenuItem(AP_MENU_ID_TOOLS_REVISIONS_AUTO)
+#if !XP_SIMPLE_MENU	
 		    MenuItem(AP_MENU_ID_TOOLS_HISTORY_PURGE)
+#endif	
 		EndSubMenu()
 	
 		BeginSubMenu(AP_MENU_ID_TOOLS_REVISIONS)
 			MenuItem(AP_MENU_ID_TOOLS_REVISIONS_MARK)
+#if !XP_SIMPLE_MENU	
 			MenuItem(AP_MENU_ID_TOOLS_REVISIONS_NEW_REVISION)
+#endif	
 		    Separator()
 	        MenuItem(AP_MENU_ID_TOOLS_REVISIONS_SHOW)
 			MenuItem(AP_MENU_ID_TOOLS_REVISIONS_SHOW_AFTER)
@@ -266,7 +313,9 @@ BeginLayout(Main,0)
 	        Separator()
 			MenuItem(AP_MENU_ID_TOOLS_REVISIONS_ACCEPT_REVISION)
 			MenuItem(AP_MENU_ID_TOOLS_REVISIONS_REJECT_REVISION)
+#if !XP_SIMPLE_MENU	
 			MenuItem(AP_MENU_ID_TOOLS_REVISIONS_PURGE)
+#endif	
 #ifdef DEBUG
 	        Separator()
 		    MenuItem(AP_MENU_ID_TOOLS_REVISIONS_MERGE_DOCUMENTS)
@@ -275,6 +324,7 @@ BeginLayout(Main,0)
 	
 	    Separator()
 
+#if !XP_SIMPLE_MENU
 		MenuItem(AP_MENU_ID_TOOLS_PLUGINS)
 		MenuItem(AP_MENU_ID_TOOLS_SCRIPTS)
 		MenuItem(AP_MENU_ID_TOOLS_MAILMERGE)
@@ -285,6 +335,7 @@ BeginLayout(Main,0)
 		Separator()
 		MenuItem(AP_MENU_ID_TOOLS_OPTIONS)
 #endif
+#endif	
 	EndSubMenu()
 
 	BeginSubMenu(AP_MENU_ID_TABLE)
@@ -340,11 +391,13 @@ BeginLayout(Main,0)
 	       MenuItem(AP_MENU_ID_TABLE_SORTCOLSDESCEND)
 	    EndSubMenu()
 #endif
+#if !XP_SIMPLE_MENU
 	    BeginSubMenu(AP_MENU_ID_TABLE_TABLETOTEXT)
 	       MenuItem(AP_MENU_ID_TABLE_TABLETOTEXTCOMMAS)
 	       MenuItem(AP_MENU_ID_TABLE_TABLETOTEXTTABS)
 	       MenuItem(AP_MENU_ID_TABLE_TABLETOTEXTCOMMASTABS)
 	    EndSubMenu()
+#endif
 		MenuItem(AP_MENU_ID_TABLE_AUTOFIT)
 #if DEBUG
 	    BeginSubMenu(AP_MENU_ID_TABLE_HEADING_ROWS_REPEAT)
@@ -354,6 +407,7 @@ BeginLayout(Main,0)
 #endif
 	EndSubMenu()
 
+#if !XP_SIMPLE_MENU
 	BeginSubMenu(AP_MENU_ID_WINDOW)
 		MenuItem(AP_MENU_ID_WINDOW_NEW)
 		Separator()
@@ -384,6 +438,7 @@ BeginLayout(Main,0)
 #endif
 		MenuItem(AP_MENU_ID_HELP_ABOUT)
 	EndSubMenu()
+#endif
 
 EndLayout()
 	
