@@ -39,7 +39,7 @@
 
 /* Define if the tables are supported
  */
-#define XHTML_TABLES_SUPPORTED
+#define XHTML_TABLES_SUPPORTED 1
 
 /* Define if meta information is supported
  */
@@ -90,11 +90,18 @@ public:
 
 	virtual void			charData (const XML_Char * buffer, int length);
 
-	virtual void		pasteFromBuffer(PD_DocumentRange * pDocRange,
+	virtual bool		pasteFromBuffer(PD_DocumentRange * pDocRange,
 										const unsigned char * pData, 
 										UT_uint32 lenData, 
 										const char * szEncoding = 0);
 
+	virtual bool  appendStrux(PTStruxType pts, const XML_Char ** attributes);
+	virtual bool  appendFmt( const XML_Char ** attributes);
+	virtual bool  appendFmt(const UT_GenericVector<XML_Char*> * pVecAttributes);
+	virtual bool  appendSpan(const UT_UCSChar * p, UT_uint32 length);
+	virtual bool  appendObject(PTObjectType pto, const XML_Char ** attributes);
+
+
 protected:
 	virtual FG_Graphic *	importImage (const XML_Char * szSrc);
 
@@ -126,7 +133,9 @@ private:
 	UT_String	m_dirname;
 
 	UT_Vector	m_divClasses;
-	UT_Vector	m_divStyles;
+	UT_GenericVector<UT_UTF8String *>	m_divStyles;
+	bool        bInTable(void);
+	bool        m_bFirstBlock;
 };
 
 #endif /* IE_IMP_XHTML_H */
