@@ -41,11 +41,14 @@ class ABI_EXPORT PieceOfText
   virtual ~PieceOfText(void);
   UT_sint32 iInLow;
   UT_sint32 iInHigh;
+  UT_sint32 nWords;
+  bool      bHasStop;
   UT_UTF8String sText;
   bool      m_bGrammarChecked;
   bool      m_bGrammarOK;
   UT_GenericVector<AbiGrammarError *> m_vecGrammarErrors;
   UT_UTF8String m_sSuggestion;
+  UT_sint32 countWords(void);
 };
 
 #endif // __Abi_GrammarUtil_h__
