@@ -46,18 +46,9 @@ GR_Abi_CharArea::GR_Abi_CharArea(GR_Graphics* graphics, GR_Font* f, const scaled
 	  size.getValue());
 #endif
 
-#if defined(XP_TARGET_COCOA) || defined (WIN32)
-  m_box = BoundingBox(GR_Abi_RenderingContext::fromAbiLayoutUnits(glyphRect.width),
+  m_box = BoundingBox(GR_Abi_RenderingContext::fromAbiLayoutUnits(glyphRect.width + glyphRect.left),
 		      GR_Abi_RenderingContext::fromAbiLayoutUnits(glyphRect.top),
 		      GR_Abi_RenderingContext::fromAbiLayoutUnits(glyphRect.height - glyphRect.top));
-#else
-  const float logicalWidth = f->measureUnremappedCharForCache(m_ch);
-  const float deviceWidth = graphics->measureUnRemappedChar(m_ch);
-
-  m_box = BoundingBox(GR_Abi_RenderingContext::fromAbiLayoutUnits(glyphRect.width * deviceWidth / logicalWidth),
-		      GR_Abi_RenderingContext::fromAbiLayoutUnits(glyphRect.top * deviceWidth / logicalWidth),
-		      GR_Abi_RenderingContext::fromAbiLayoutUnits(glyphRect.height - glyphRect.top) * deviceWidth / logicalWidth);
-#endif
 #endif
 }
 
