@@ -45,7 +45,11 @@
 ODi_Style_Style::ODi_Style_Style(ODi_ElementStack& rElementStack) :
                        ODi_ListenerState("StyleStyle", rElementStack),
                        m_pParentStyle(NULL),
-                       m_pNextStyle(NULL)
+                       m_pNextStyle(NULL),
+                       m_haveTopBorder(HAVE_BORDER_UNSPECIFIED),
+                       m_haveBottomBorder(HAVE_BORDER_UNSPECIFIED),
+                       m_haveLeftBorder(HAVE_BORDER_UNSPECIFIED),
+                       m_haveRightBorder(HAVE_BORDER_UNSPECIFIED)
 {
     if (rElementStack.hasElement("office:automatic-styles")) {
         m_bAutomatic = true;
@@ -396,8 +400,8 @@ void ODi_Style_Style::_parse_style_textProperties(const XML_Char** ppProps) {
     
     pVal = UT_getAttribute("fo:font-style", ppProps);
     if (pVal) {
-        if (!UT_strcmp(pVal, "italic")) {
-            m_fontStyle = "italic";
+        if (!UT_strcmp(pVal, "italic") || !UT_strcmp(pVal, "normal")) {
+            m_fontStyle = pVal;
         }
     }
     
@@ -499,36 +503,44 @@ void ODi_Style_Style::_parse_style_tableCellProperties(const XML_Char** ppProps)
     // If "fo:border" is defined, its value will fill all "fo:border-*"
     pVal = UT_getAttribute("fo:border", ppProps);
     if (pVal) {
-        _stripColorLength(m_borderTop_color, m_borderTop_thickness, pVal);
+        _stripColorLength(m_borderTop_color, m_borderTop_thickness,
+                          m_haveTopBorder, pVal);
         
         m_borderBottom_color = m_borderTop_color;
         m_borderBottom_thickness = m_borderTop_thickness;
+        m_haveBottomBorder = m_haveTopBorder;
         
         m_borderLeft_color = m_borderTop_color;
         m_borderLeft_thickness = m_borderTop_thickness;
+        m_haveLeftBorder = m_haveTopBorder;
         
         m_borderRight_color = m_borderTop_color;
         m_borderRight_thickness = m_borderTop_thickness;
+        m_haveRightBorder = m_haveTopBorder;
         
     } else {
         pVal = UT_getAttribute("fo:border-top", ppProps);
         if (pVal) {
-            _stripColorLength(m_borderTop_color, m_borderTop_thickness, pVal);
+            _stripColorLength(m_borderTop_color, m_borderTop_thickness,
+                              m_haveTopBorder, pVal);
         }
         
         pVal = UT_getAttribute("fo:border-bottom", ppProps);
         if (pVal) {
-            _stripColorLength(m_borderBottom_color, m_borderBottom_thickness, pVal);
+            _stripColorLength(m_borderBottom_color, m_borderBottom_thickness,
+                              m_haveBottomBorder, pVal);
         }
         
         pVal = UT_getAttribute("fo:border-left", ppProps);
         if (pVal) {
-            _stripColorLength(m_borderLeft_color, m_borderLeft_thickness, pVal);
+            _stripColorLength(m_borderLeft_color, m_borderLeft_thickness,
+                              m_haveLeftBorder, pVal);
         }
         
         pVal = UT_getAttribute("fo:border-right", ppProps);
         if (pVal) {
-            _stripColorLength(m_borderRight_color, m_borderRight_thickness, pVal);
+            _stripColorLength(m_borderRight_color, m_borderRight_thickness,
+                              m_haveRightBorder, pVal);
         }
     }
     
@@ -714,9 +726,9 @@ void ODi_Style_Style::buildAbiPropsAttrString(ODi_FontFaceDecls& rFontFaceDecls)
  * @param rProps The string that will have appended to it the properties of this
  *               style.
  */
-void ODi_Style_Style::getAbiPropsAttrString(UT_UTF8String& rProps) const {
+void ODi_Style_Style::getAbiPropsAttrString(UT_UTF8String& rProps, bool appendParentProps) const {
 
-        if (m_pParentStyle) {
+        if (appendParentProps && m_pParentStyle) {
             m_pParentStyle->getAbiPropsAttrString(rProps);
         }
     
@@ -750,19 +762,31 @@ const UT_UTF8String* ODi_Style_Style::getWrap(bool local) const {
 
 
 /**
- * If pString is "0.0556in solid #0000ff", rColor will receive "#0000ff" and
- * rLength "0.0556in".
+ * If pString is "0.0556in solid #0000ff", rColor will receive "#0000ff",
+ * rLength "0.0556in" and rHaveBorder "yes".
+ * 
+ * If pString is "none", both rColor and rLenght will be empty and
+ * rHaveBorder will be "no"
  */
 void ODi_Style_Style::_stripColorLength(UT_UTF8String& rColor,
-                                       UT_UTF8String& rLength,
-                                       const XML_Char* pString) const {
+                                  UT_UTF8String& rLength,
+                                  ODi_Style_Style::HAVE_BORDER& rHaveBorder,
+                                  const XML_Char* pString) const {
                                         
     UT_uint16 i, start;
     bool hasWord;
-    
+
     rColor.clear();
     rLength.clear();
     
+    if (!UT_strcmp(pString, "none")) {
+        // Color and length remain empty.
+        rHaveBorder = HAVE_BORDER_NO;
+        return;
+    } else {
+        rHaveBorder = HAVE_BORDER_YES;
+    }
+    
     i = 0;
     start = 0;
     hasWord = true;
