@@ -149,9 +149,23 @@ void ODi_TextContent_ListenerState::startElement (const XML_Char* pName,
         pStyle = m_pStyles->getParagraphStyle(pStyleName, m_bOnContentStream);
         UT_ASSERT(pStyle);
         
-        m_headingStyles.ins(UT_UTF8String(pOutlineLevel),
-                            pStyle->getDisplayName());
+        if (pStyle->isAutomatic()) {
 
+            if (pStyle->getParent() != NULL) {
+                m_headingStyles.ins(UT_UTF8String(pOutlineLevel),
+                                    pStyle->getParent()->getDisplayName());
+            } else {
+                UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+                // This is not expected from a well formed file.
+                // So, it's corrputed. But we can ignore this error without
+                // compromising the doc load as a whole
+                // (the TOC will not be displayed correctly, though).
+            }
+            
+        } else {
+            m_headingStyles.ins(UT_UTF8String(pOutlineLevel),
+                                pStyle->getDisplayName());
+        }
         
         // It's so big that it deserves its own function.
         _startParagraphElement(pName, ppAtts, rAction);
@@ -261,6 +275,7 @@ void ODi_TextContent_ListenerState::startElement (const XML_Char* pName,
         
     } else if (!UT_strcmp(pName, "text:a")) {
         
+        _flush();
         const XML_Char * xlink_atts[3];
         xlink_atts[0] = "xlink:href";
         xlink_atts[1] = UT_getAttribute("xlink:href", ppAtts);
@@ -831,12 +846,11 @@ void ODi_TextContent_ListenerState::_openAbiSection(
     if (pMasterPageName != NULL && !pMasterPageName->empty()) {
         
         pMasterPageStyle = m_pStyles->getMasterPageStyle(pMasterPageName->utf8_str());
-        UT_ASSERT(pMasterPageStyle);
         
-        UT_ASSERT(pMasterPageStyle->getPageLayout());
-        
-        allProps = pMasterPageStyle->getSectionProps();
-        UT_ASSERT(!allProps.empty());
+        if (pMasterPageStyle && pMasterPageStyle->getPageLayout()) {
+            allProps = pMasterPageStyle->getSectionProps();
+            UT_ASSERT(!allProps.empty());
+        }
         
         m_openedFirstAbiSection = true;
     }
@@ -1100,9 +1114,14 @@ void ODi_TextContent_ListenerState::_startParagraphElement (const XML_Char* pNam
                 if (pStyle->isAutomatic()) {
                     // Automatic styles are not defined on the document, so, we
                     // just paste its properties.
-                    pStyle->getAbiPropsAttrString(props);
+                    pStyle->getAbiPropsAttrString(props, FALSE);
                     ppAtts[i++] = "props";
                     ppAtts[i++] = props.utf8_str();
+                    
+                    if (pStyle->getParent() != NULL) {
+                        ppAtts[i++] = "style";
+                        ppAtts[i++] = pStyle->getParent()->getDisplayName().utf8_str();
+                    }
                 } else {
                     // We refer to the style
                     ppAtts[i++] = "style";
