@@ -185,10 +185,7 @@ private:
 
     int							        m_iCurrentListLevel;
     bool								m_bInCell;
-	//needed for correct conversion of complicated tables
-    int							        m_iNumCoveredTableCellsInRow;
-	
-	
+
 	// HACK HACK HACK
 	int									m_bHdrFtrOpenCount;
 };
