@@ -386,6 +386,6 @@ else
 
 	echo ""
 	echo "(1) Use the Finder's View Options to set the image background."
-	echo "(2) Then: hdiutil convert AbiWord-2.2.2.dmg -format UDZO -o AbiWord-2.2.2-UDZO9.dmg -imagekey zlib-level=9"
+	echo "(2) Then: hdiutil convert AbiWord.dmg -format UDZO -o AbiWord-2.4.x.dmg -imagekey zlib-level=9"
 	echo ""
 fi
